@@ -54,9 +54,9 @@ public:
         HasMenuBar     = 0x0001,
         MenuBarVisible = 0x0002
     };
-    Q_DECLARE_FLAGS(ViewFlags, ViewFlag);
+    Q_DECLARE_FLAGS(ViewFlags, ViewFlag)
 
-    ViewBase(QWidget* parent, QString id, Qt::WindowFlags f, ViewFlags vflags, QString guiProfileId, KActionCollection* actionCollection = 0);
+    ViewBase(QWidget* parent, const QString &id, Qt::WindowFlags f, ViewFlags vflags, const QString &guiProfileId, KActionCollection* actionCollection = nullptr);
     // The GUI profile will not be removed on destruction,
     // as it is pooled and might be applied to a new View.
     virtual ~ViewBase() = default;
@@ -84,8 +84,8 @@ public:
 
     ProfControl *findMdw(const QString &mdwId, GuiVisibility visibility = GuiVisibility::Default) const;
 
-    KActionCollection *actionCollection() const		{ return (_actions); };
-    const QList<Mixer*> &getMixers() const		{ return (_mixers); };
+    KActionCollection *actionCollection() const		{ return (_actions); }
+    const QList<Mixer*> &getMixers() const		{ return (_mixers); }
 
     int mixDeviceCount() const				{ return (_mdws.count()); }
     QWidget *mixDeviceAt(int i) const			{ return (_mdws.at(i)); }
@@ -139,7 +139,7 @@ protected:
     /**
      * Popup stuff
      */
-    void contextMenuEvent(QContextMenuEvent *ev) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *ev) override;
     virtual void showContextMenu();
 
     // Creates a suitable representation for the given MixDevice.
@@ -163,6 +163,6 @@ private slots:
    void toggleMenuBarSlot();
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(ViewBase::ViewFlags);
+Q_DECLARE_OPERATORS_FOR_FLAGS(ViewBase::ViewFlags)
 
 #endif
